@@ -67,3 +67,42 @@ sub run
 
 1;# return true:
 
+=pod
+
+=head1 NAME
+
+Apache2::ASP::ASPHandler - handler for all *.asp requests
+
+=head1 SYNOPSIS
+
+Internal use only.
+
+=head1 DESCRIPTION
+
+This class is the L<Apache2::ASP::HTTPHandler> subclass responsible for handling
+all requests to C<*.asp> scripts.
+
+=head1 BUGS
+
+It's possible that some bugs have found their way into this release.
+
+Use RT L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Apache2-ASP> to submit bug reports.
+
+=head1 HOMEPAGE
+
+Please visit the Apache2::ASP homepage at L<http://www.devstack.com/> to see examples
+of Apache2::ASP in action.
+
+=head1 AUTHOR
+
+John Drago L<mailto:jdrago_999@yahoo.com>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright 2007 John Drago, All rights reserved.
+
+This software is free software.  It may be used and distributed under the
+same terms as Perl itself.
+
+=cut
+
